@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute Halstead complexity metrics
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0400';
 
 use Moo;
 use strictures 2;
@@ -159,7 +159,7 @@ sub BUILD {
 }
 
 
-sub dump {
+sub report {
     my ($self) = @_;
     printf "Total operators = %d, Total operands = %d\n", $self->n_operators, $self->n_operands;
     printf "Distinct operators = %d, Distinct operands = %d\n", $self->n_distinct_operators, $self->n_distinct_operands;
@@ -176,6 +176,29 @@ sub dump {
     printf "Delivered bugs = %.3f\n", $self->delivered_bugs;
 }
 
+
+sub dump {
+    my ($self) = @_;
+    return {
+        n_operators => $self->n_operators,
+        n_operands => $self->n_operands,
+        n_distinct_operators => $self->n_distinct_operators,
+        n_distinct_operands => $self->n_distinct_operands,
+        prog_vocab => $self->prog_vocab,
+        prog_length => $self->prog_length,
+        est_prog_length => $self->est_prog_length,
+        volume => $self->volume,
+        min_volume => $self->min_volume,
+        difficulty => $self->difficulty,
+        level => $self->level,
+        lang_level => $self->lang_level,
+        intel_content => $self->intel_content,
+        effort => $self->effort,
+        time_to_program => $self->time_to_program,
+        delivered_bugs => $self->delivered_bugs,
+    };
+}
+
 sub _is_operand {
     my $key = shift;
     return $key eq 'PPI::Token::Comment'
@@ -205,7 +228,7 @@ Perl::Metrics::Halstead - Compute Halstead complexity metrics
 
 =head1 VERSION
 
-version 0.0300
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -213,7 +236,9 @@ version 0.0300
 
   my $pmh = Perl::Metrics::Halstead->new(file => '/some/perl/code.pl');
 
-  $pmh->dump;
+  my $metrics = $pmh->dump;
+
+  $pmh->report;
 
 =head1 DESCRIPTION
 
@@ -252,7 +277,7 @@ The number of distinct operators.  This is a computed attribute.
 
   $n_distinct_operands = $pmh->n_distinct_operands;
 
-The number of distinct operators.  This is a computed attribute.
+The number of distinct operands.  This is a computed attribute.
 
 =head2 prog_vocab
 
@@ -339,12 +364,18 @@ Create a new C<Perl::Metrics::Halstead> object given the B<file> argument.
 
 Process the given B<file> into the computed metrics.
 
-=head2 dump()
+=head2 report()
 
-  $pmh->dump();
+  $pmh->report();
 
 Print the computed metrics to C<STDOUT>.
 
+=head2 dump()
+
+  $metrics = $pmh->dump();
+
+Return a hashref of the metrics and their computed values.
+
 =head1 SEE ALSO
 
 The F<t/01-methods.t> file in this distribution.
